#!ibsh -f

# a simple interface for an EG&G Ortec Counter

set device [gpib find orteccnt]

set ok "%000000069\n"

gpib sic   $device
gpib ren   $device 1
gpib clear $device

proc displ_refresh {} {
	global result device ok

	set result ""
	.light configure -background blue
	update
	while { 1 } {
		set ret [gpib read $device 200]
		if { $ret == $ok } {
			.light configure -background green
			update
			break
		}
		if { $ret == "ERROR" } {
			.light configure -background red
			update
			break
		}
		append result $ret
	}
	.entry delete 0 end
}

proc count_cycle {} {
	global device

	option add *Barchart.Geometry 150x400
	option add *Barchart.BarWidthPct 20
	option add *Barchart.AxisThickness 0
	option add *Barchart.ShowLegend false

	set counts 0
	set max 10
	gpib write $device "start\n"
	displ_refresh

	toplevel .top
	button .top.bq -text "Quit" -command {destroy .top;return}
	barchart .top.bar -title "Counts" -relief flat -xticks 0 \
                          -xlabel "" -ylabel Counts -ysubticks 10

	set colors { red green blue purple orange brown cyan black pink magenta }
	.top.bar insert 2 -y $max -fg white
	.top.bar insert 1 -y $counts -fg magenta

	pack append .top .top.bar {top fill}  .top.bq {bottom fill}

	set i 0
	while { $i < 1000 } {
		gpib write $device "START\n"
		displ_refresh
		after 1000
		gpib write $device "STOP\n"
		displ_refresh
		gpib write $device "SHOW_COUNTS\n"
		scan [gpib read $device 200] "%d;%d;" counts dummy
		gpib read $device 200
		.top.bar insert 1 -y $counts -fg magenta
		update
		incr i
		gpib write $device "CL_COU\n"
		displ_refresh
		if { $counts > $max } {
			set max $counts
			.top.bar insert 2 -y $max -fg white
		}
	}
	gpib write $device "STOP\n";displ_refresh

}

label  .lab  -text "Ortec Talk Radio" -font -adobe-times-bold-r-normal--18-180-75-75-p-99-iso8859-1
label .light -width 1 -height 1 -background green -relief ridge -text " "
label  .val  -width 45  -textvariable result -relief sunken -font -adobe-helvetica-bold-r-normal--24-240-75-75-p-138-iso8859-1
label .msg -text "Input:" 
entry .entry -relief sunken -textvariable cmd  -font -adobe-times-bold-r-normal--18-180-75-75-p-99-iso8859-1
label .nixx -text "  "

button .but1 -text "Quit" -height 2 -command { set block 1; update idletasks ;gpib close $device ; exit}
button .but2 -text "Reset GPIB"  -height 2 -command {gpib clear $device; displ_refresh }
button .but3 -text "Start" -height 2 -command {gpib write $device "START\n";displ_refresh}
button .but4 -text "Stop" -height 2 -command {gpib write $device "STOP\n";displ_refresh}
button .but7 -text "Clear" -height 2 -command {gpib write $device "CL_COU\n";displ_refresh}
button .but5 -text "Show Counts" -height 2 -command {gpib write $device "SHOW_COUNTS\n"; displ_refresh }
button .but6 -text "Cycle" -height 2 -command {count_cycle}

pack append . .lab {top fillx} .msg {left top fillx expand} .entry { top fillx} .nixx {top fillx } .val { top fillx } .light {right fillx }  
pack append . .but3 { left fillx expand} .but4 { left fillx expand}  \
              .but7 {left fillx expand} .but5 {left fillx expand} \
              .but2 {left fillx expand } .but6 { left fillx expand}  .but1 { left fillx expand padx 3m}



bind .entry <Return> {append cmd "\n";gpib write $device $cmd;displ_refresh}

displ_refresh










